@@ -8,8 +8,7 @@
  */
 
 #include <ctype.h>
-
-#include "config.h"
+#include <string.h>
 
 #include "snapd-markdown-parser.h"
 #include "snapd-markdown-node.h"
