@@ -37,6 +37,7 @@ typedef struct _MockPlug MockPlug;
 typedef struct _MockPrice MockPrice;
 typedef struct _MockSlot MockSlot;
 typedef struct _MockSnap MockSnap;
+typedef struct _MockSnapshot MockSnapshot;
 typedef struct _MockTask MockTask;
 typedef struct _MockTrack MockTrack;
 
@@ -181,6 +182,9 @@ MockSnap       *mock_snapd_add_snap               (MockSnapd     *snapd,
 MockSnap       *mock_snapd_find_snap              (MockSnapd     *snapd,
                                                    const gchar   *name);
 
+MockSnapshot   *mock_snapd_find_snapshot          (MockSnapd     *snapd,
+                                                   const gchar   *name);
+
 void            mock_snapd_add_store_section      (MockSnapd     *snapd,
                                                    const gchar   *name);
 
@@ -384,6 +388,9 @@ void            mock_snap_set_type                (MockSnap      *snap,
 void            mock_snap_set_version             (MockSnap      *snap,
                                                    const gchar   *version);
 
+void            mock_snap_set_website             (MockSnap      *snap,
+                                                   const gchar   *website);
+
 void            mock_snap_add_store_section       (MockSnap      *snap,
                                                    const gchar   *section);
 
